@@ -18,7 +18,7 @@ import tempfile
 import uuid
 from dataclasses import dataclass
 from enum import Enum
-from typing import Callable, Optional, Tuple, Union
+from typing import Callable, Dict, Optional, Tuple, Union
 
 from datatailr import ACL, Environment, User, is_dt_installed
 from datatailr.wrapper import dt__Job
@@ -26,7 +26,7 @@ from datatailr.scheduler.constants import DEFAULT_TASK_MEMORY, DEFAULT_TASK_CPU
 from datatailr.build.image import Image
 from datatailr.errors import BatchJobError
 from datatailr.logging import DatatailrLogger
-from datatailr.utils import run_shell_command
+from datatailr.utils import run_shell_command, dict_to_env_vars
 
 logger = DatatailrLogger(os.path.abspath(__file__)).get_logger()
 __client__ = dt__Job()
@@ -148,6 +148,7 @@ class Job:
         python_requirements: str = "",
         build_script_pre: str = "",
         build_script_post: str = "",
+        env_vars: Dict[str, str | int | float | bool] = {},
         type: Optional[JobType] = JobType.UNKNOWN,
         entrypoint: Optional[EntryPoint] = None,
         update_existing: bool = False,
@@ -186,6 +187,7 @@ class Job:
         self.type = type if entrypoint is None else entrypoint.type
         self.entrypoint = entrypoint
         self.__id = str(uuid.uuid4())
+        self.__env_vars = env_vars
 
     @property
     def id(self) -> str:
@@ -237,8 +239,12 @@ class Job:
             "memory": self.resources.memory,
             "cpu": self.resources.cpu,
         }
+        if self.type == JobType.EXCEL:
+            if "DATATAILR_LOCAL" not in self.__env_vars:
+                self.__env_vars.update({"DATATAILR_LOCAL": "false"})
         if self.type != JobType.BATCH:
             job_dict["entrypoint"] = str(self.entrypoint) if self.entrypoint else None
+            job_dict["env"] = dict_to_env_vars(self.__env_vars)
         return job_dict
 
     def from_dict(self, job_dict: dict):
