@@ -32,7 +32,7 @@ from datatailr.scheduler.base import (
 from datatailr.scheduler.constants import DEFAULT_TASK_CPU, DEFAULT_TASK_MEMORY
 from datatailr.scheduler.arguments_cache import ArgumentsCache
 from datatailr.scheduler.schedule import Schedule
-from datatailr.utils import is_dt_installed
+from datatailr.utils import is_dt_installed, dict_to_env_vars
 
 __DAG_CONTEXT__: contextvars.ContextVar = contextvars.ContextVar("dag_context")
 __ARGUMENTS_CACHE__ = ArgumentsCache()
@@ -97,6 +97,7 @@ class BatchJob:
         dependencies: Sequence[Union[str, BatchJob]] = [],
         dag: Optional[Batch] = get_current_manager(),
         argument_mapping: Dict[str, str] = {},
+        env_vars: Dict[str, str | int | float | bool] = {},
     ):
         self.name = name
         self.entrypoint = entrypoint
@@ -112,6 +113,7 @@ class BatchJob:
         assert all(
             isinstance(dep, int) for dep in self.dependencies
         ), "All dependencies must be integers representing job IDs."
+        self.__env_vars = env_vars
         self.dag.add_job(self)
         self.argument_mapping = argument_mapping or {}
 
@@ -193,6 +195,16 @@ class BatchJob:
     def __setstate__(self, state: dict):
         self.__dict__.update(state)
 
+    def update_env_vars(self, env_vars: Dict[str, str | int | float | bool]) -> None:
+        """
+        Update the environment variables for the BatchJob instance.
+
+        :param env_vars: A dictionary of environment variables to update.
+        """
+        env = env_vars.copy()
+        env.update(self.__env_vars)
+        self.__env_vars = env
+
     def to_dict(self):
         """
         Convert the BatchJob instance to a dictionary representation.
@@ -205,6 +217,7 @@ class BatchJob:
             "memory": self.resources.memory if self.resources else DEFAULT_TASK_MEMORY,
             "cpu": self.resources.cpu if self.resources else DEFAULT_TASK_CPU,
             "depends_on": list(self.dependencies),
+            "env": dict_to_env_vars(self.__env_vars),
         }
 
     def to_json(self):
@@ -308,6 +321,7 @@ class Batch(Job):
         python_requirements: str = "",
         build_script_pre: str = "",
         build_script_post: str = "",
+        env_vars: Dict[str, str | int | float | bool] = {},
     ):
         super().__init__(
             environment=environment,
@@ -327,6 +341,7 @@ class Batch(Job):
         self.__BATCH_JOB_NAMES__: Dict[str, int] = {}
         self.__local_run = local_run
         self.__schedule = schedule
+        self.__env_vars = env_vars
 
     @property
     def next_job_id(self):
@@ -369,6 +384,7 @@ class Batch(Job):
                 f"Function {job.entrypoint.function_name} is defined in a different module: "
                 f"{package_path_to_module} != {image_path_to_module}"
             )
+        job.update_env_vars(self.__env_vars)
         self.__jobs.append(job)
 
     def is_job_in(self, job: BatchJob) -> bool:
