@@ -20,15 +20,21 @@ logger = DatatailrLogger(os.path.abspath(__file__)).get_logger()
 
 def run():
     logger.info("Starting Datatailr excel add-in...")
-    entrypoint = os.environ.get("DATATAILR_ENTRYPOINT")
-    # hostname = os.environ.get("DATATAILR_HOST")
 
+    entrypoint = os.environ.get("DATATAILR_ENTRYPOINT")
     if entrypoint is None:
         raise ValueError("Environment variable 'DATATAILR_ENTRYPOINT' is not set.")
 
-    # if hostname is None:
-    #     raise ValueError("Environment variable 'DATATAILR_HOST' is not set.")
+    local = os.environ.get("DATATAILR_LOCAL", False) in ("1", "true", "True", "TRUE")
+    if local:
+        hostname = "localhost.excel.datatailr.com"
+        local_flag = "-l"
+    else:
+        hostname = os.environ.get("DATATAILR_HOST")
+        if hostname is None:
+            raise ValueError("Environment variable 'DATATAILR_HOST' is not set.")
+        local_flag = ""
 
-    # entrypoint = f'./dt-excel.sh -n -H "{hostname}" -p 8080 "{entrypoint}"'
+    entrypoint = f'/opt/datatailr/bin/dt-excel.sh -n -H "{hostname}" {local_flag} -p 8080 -w 8000 {entrypoint}'
     logger.info(f"Running entrypoint: {entrypoint}")
     subprocess.run(entrypoint, shell=True)
